==> humhub-1.6.3.tar.gz: humhub-1.6.3/protected/humhub/modules/user/messages/es/base.php <==
<?php
return array (
  '<strong>Following</strong> user' => '<strong>Siguiendo</strong> a usuario',
  '<strong>Member</strong> in these spaces' => '<strong>Miembros</strong> en estos espacios',
  '<strong>User</strong> followers' => 'Seguidores de <strong>usuario</strong>',
  '<strong>User</strong> tags' => 'Etiquetas de <strong>usuario</strong>',
  'Allows access to your about page with personal information' => 'Permite accesar a tu página Acerca de con información personal',
  'Auth Mode' => 'Modo de autenticación',
  'Basic Settings' => 'Ajustes básicos',
  'Change Email' => 'Cambiar correo',
  'Change Password' => 'Cambiar clave',
  'Change Username' => 'Cambiar nombre de usuario',
  'Confirm new password' => 'Confirmar clave',
  'Connect account' => 'Conectar cuenta',
  'Connected Accounts' => 'Cuentas Conectadas',
  'Connected accounts' => 'Cuentas conectadas',
  'Created at' => 'Creado el',
  'Created by' => 'Creado por',
  'Current Password' => 'Clave actual',
  'Currently in use' => 'Actualmente en uso',
  'Default Space' => 'Espacio predeterminado',
  'Delete' => 'Borrar',
  'Delete Account' => 'Borrar cuenta',
  'Description' => 'Descripción',
  'Disconnect account' => 'Desconectar cuenta',
  'E-Mail is already in use! - Try forgot password.' => '¡Este correo electrónico ya está en uso! - Prueba a restablecer tu contraseña.',
  'Email' => 'Correo electrónico',
  'Follow' => 'Seguir',
  'General' => 'General',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Aquí puede conectar a un proveedor de servicios externo para utilizar servicios externos como un solo registro o autenticación.',
  'Language' => 'Idioma',
  'Last Login' => 'Último registro',
  'Manager' => 'Administrador',
  'Missing E-Mail Attribute from AuthClient.' => 'Falta el atributo E-Mail en AuthClient.',
  'Missing ID AuthClient Attribute from AuthClient.' => 'Falta el atributo ID AuthClient en AuthClient.',
  'Modules' => 'Módulos',
  'My Account' => 'Mi Cuenta',
  'Name' => 'Nombre',
  'New password' => 'Nueva contraseña',
  'No users found.' => 'No se encontraron usuarios.',
  'Notifications' => 'Notificaciones',
  'Password' => 'Contraseña',
  'Permission' => 'Permiso',
  'Profile' => 'Perfil',
  'Profile posts only' => 'Sólo entradas de perfil',
  'Register now and participate!' => '¡Regístrese ahora y participe!',
  'Security' => 'Seguridad',
  'Settings' => 'Ajustes',
  'Show At Directory' => 'Mostrar en Directorio',
  'Show At Registration' => 'Mostrar en Registro',
  'Show all content' => 'Mostrar todo el contenido',
  'Sign in' => 'Iniciar sesión',
  'Sign in / up' => 'Entrar / Registrarse',
  'Sign up' => 'Registrarse',
  'Sign up now' => 'Registrarse ahora',
  'Sort order' => 'Ordenado por',
  'Source' => 'Fuente',
  'Space ID' => 'ID del Espacio',
  'Status' => 'Estado',
  'Tags' => 'Etiquetas',
  'Unfollow' => 'Dejar de seguir',
  'Unknown user status!' => 'Estado del usuario desconocido.',
  'Updated at' => 'Actualizado el',
  'Updated by' => 'Actualizado por',
  'User' => 'Usuario',
  'User has been invited.' => 'El usuario ha sido invitado.',
  'User with the same email already exists but isn\'t linked to you. Login using your email first to link it.' => 'Un usuario con el mismo correo ya existe pero está no está conectado con usted. Ingrese con su correo primero para enlazarlo.',
  'Username' => 'Nombre de usuario',
  'Username contains invalid characters.' => 'Ese nombre de usuario contiene caracteres no válidos.',
  'View your about page' => 'Ver tu página Acerca de',
  'Visibility' => 'Visibilidad',
  'Welcome to %appName%' => 'Bienvenido a %appName%',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Bienvenido a %appName%.Por favor, haz clic en el botón de abajo para proceder a registrarte.',
  'You got an invite' => 'Tiene una invitación',
  'You\'re not registered.' => 'Usted no está registrado.',
  'You\'ve been invited to join {space} on {appName}' => 'Ha sido invitado a unirse a {space} en {appName}',
  'Your account is disabled!' => '¡Su cuenta está deshabilitada!',
  'Your account is not approved yet!' => '¡Su cuenta todavía no ha sido aprobada!',
  'Your new password must not be equal your current password!' => 'Tu nueva clave no debe ser igual a la actual',
  'invited you to join {name}.' => 'le ha invitado a unirse a {name}.',
  'invited you to join {space} on {name}.' => 'le ha invitado a unerse a {space} en {name}.',
  'or' => 'o',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/user/messages/es/base.php <==
<?php
return array (
  '<strong>Following</strong> user' => '<strong>Siguiendo</strong> a usuario',
  '<strong>Member</strong> in these spaces' => '<strong>Miembros</strong> en estos espacios',
  '<strong>User</strong> followers' => 'Seguidores de <strong>usuario</strong>',
  '<strong>User</strong> tags' => 'Etiquetas de <strong>usuario</strong>',
  'Allows access to your about page with personal information' => 'Permite accesar a tu página Acerca de con información personal',
  'Auth Mode' => 'Modo de autenticación',
  'Basic Settings' => 'Ajustes básicos',
  'Change Email' => 'Cambiar correo',
  'Change Password' => 'Cambiar clave',
  'Change Username' => 'Cambiar nombre de usuario',
  'Confirm new password' => 'Confirmar clave',
  'Connect account' => 'Conectar cuenta',
  'Connected Accounts' => 'Cuentas Conectadas',
  'Connected accounts' => 'Cuentas conectadas',
  'Created at' => 'Creado el',
  'Created by' => 'Creado por',
  'Current password' => 'Clave actual',
  'Currently in use' => 'Actualmente en uso',
  'Default Group' => 'Grupo predeterminado',
  'Default Space' => 'Espacio predeterminado',
  'Delete' => 'Borrar',
  'Delete Account' => 'Borrar cuenta',
  'Description' => 'Descripción',
  'Disconnect account' => 'Desconectar cuenta',
  'E-Mail is already in use! - Try forgot password.' => '¡Este correo electrónico ya está en uso! - Prueba a restablecer tu contraseña.',
  'Email' => 'Correo electrónico',
  'Enable Notifications' => 'Activar notificaciones',
  'Follow' => 'Seguir',
  'Force password change upon first login' => 'Obligar a cambiar la clave la primera vez que se acceda',
  'Force password change upon next login' => 'Obligar a cambiar la clave la siguiente vez que se acceda',
  'General' => 'General',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Aquí puede conectar a un proveedor de servicios externo para utilizar servicios externos como un solo registro o autenticación.',
  'Language' => 'Idioma',
  'Last Login' => 'Último registro',
  'Manager' => 'Administrador',
  'Missing E-Mail Attribute from AuthClient.' => 'Falta el atributo E-Mail en AuthClient.',
  'Missing ID AuthClient Attribute from AuthClient.' => 'Falta el atributo ID AuthClient en AuthClient.',
  'Modules' => 'Módulos',
  'My Account' => 'Mi Cuenta',
  'Name' => 'Nombre',
  'New password' => 'Nueva contraseña',
  'No users found.' => 'No se encontraron usuarios.',
  'Notifications' => 'Notificaciones',
  'Password' => 'Contraseña',
  'Password changed' => 'Clave cambiada',
  'Password needs to be at least {chars} characters long.' => 'La contraseña tiene que tener al menos {chars} caracteres.',
  'Permission' => 'Permiso',
  'Profile' => 'Perfil',
  'Profile posts only' => 'Sólo entradas de perfil',
  'Register now and participate!' => '¡Regístrese ahora y participe!',
  'Security' => 'Seguridad',
  'Settings' => 'Ajustes',
  'Show At Directory' => 'Mostrar en Directorio',
  'Show At Registration' => 'Mostrar en Registro',
  'Show all content' => 'Mostrar todo el contenido',
  'Sign in' => 'Iniciar sesión',
  'Sign in / up' => 'Entrar / Registrarse',
  'Sign up' => 'Registrarse',
  'Sign up now' => 'Registrarse ahora',
  'Sort order' => 'Ordenado por',
  'Source' => 'Fuente',
  'Status' => 'Estado',
  'Tags' => 'Etiquetas',
  'Unfollow' => 'Dejar de seguir',
  'Unknown user status!' => 'Estado del usuario desconocido.',
  'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Intentos de inicio de sesión fallidos desde el último inicio de sesión: {failedLoginAttemptsCount}',
  'Updated at' => 'Actualizado el',
  'Updated by' => 'Actualizado por',
  'User' => 'Usuario',
  'User has been invited.' => 'El usuario ha sido invitado.',
  'Username' => 'Nombre de usuario',
  'Username contains invalid characters.' => 'Ese nombre de usuario contiene caracteres no válidos.',
  'View your about page' => 'Ver tu página Acerca de',
  'Visibility' => 'Visibilidad',
  'Welcome to %appName%' => 'Bienvenido a %appName%',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Bienvenido a %appName%.Por favor, haz clic en el botón de abajo para proceder a registrarte.',
  'You got an invite' => 'Tiene una invitación',
  'You\'re not registered.' => 'Usted no está registrado.',
  'You\'ve been invited to join {space} on {appName}' => 'Ha sido invitado a unirse a {space} en {appName}',
  'Your account is disabled!' => '¡Su cuenta está deshabilitada!',
  'Your account is not approved yet!' => '¡Su cuenta todavía no ha sido aprobada!',
  'Your are already logged in! - Logout first!' => '¡Ya estás autenticado! ¡Antes tienes que salir!',
  'Your new password must not be equal your current password!' => 'Tu nueva clave no debe ser igual a la actual',
  'invited you to join {name}.' => 'le ha invitado a unirse a {name}.',
  'invited you to join {space} on {name}.' => 'le ha invitado a unerse a {space} en {name}.',
  'or' => 'o',
);
